@@ -22,7 +22,7 @@ def to_xml(ctx, path, output):
     # Services available
     spinner = Halo(spinner="dots")
     spinner.start()
-    Services(ctx)
+    services = Services(ctx, check_up=True)
     spinner.succeed(f"Found file: {path}\n ")
 
     endpoints = ctx.obj["config"]["endpoints"]
@@ -32,8 +32,8 @@ def to_xml(ctx, path, output):
         path,
         output,
         endpoints["extractor"],
-        None if "vat_validation" not in endpoints else endpoints["vat_validation"],
-        None if "validation" not in endpoints else endpoints["validation"],
-        ctx.obj["token"],
+        getattr(services, "vat_validation", None),
+        getattr(services, "validation", None),
+        getattr(services, "token", None),
     )
     spinner.succeed("Converted invoice to xml")
