@@ -1,7 +1,6 @@
 import os
-from concurrent.futures import ThreadPoolExecutor as Executor
+from concurrent.futures import ThreadPoolExecutor, as_completed
 from pathlib import Path
-from itertools import chain
 
 import click
 from filetype import guess
@@ -9,29 +8,7 @@ from filetype import guess
 from ..services.requests import extract_invoice, validation, validate_vat
 
 
-def read_pdf(pdf_path):
-    with open(pdf_path, "rb") as pdf:
-        pdf = pdf.read()
-
-    return (pdf_path, pdf)
-
-
-class InvoiceExtractorException(Exception):
-    """Raised when the Invoice Extractor service returns an error."""
-
-    pass
-
-
-def run_requests(
-    workers,
-    path,
-    extractor_endpoint,
-    vat_validation_endpoint,
-    validation_endpoint,
-    token,
-):
-    types = ("*.pdf", "*.tif", "*.tiff", "*.png", "*.jpg")
-    file_count = 0
+def run_requests(workers, path, services):
     single_fieldnames = {
         "file_name": (None, None, None),
         "error_message": (None, None, None),
@@ -41,75 +18,53 @@ def run_requests(
         "row_number": (None, None, None),
     }
     default_cols = set().union(single_fieldnames.keys(), multi_fieldnames.keys())
-    result = {}
-    vat_validation_result = {}
+    files = get_filenames(os.path.join(os.getcwd(), path))
+    result, vat_validation_result = {}, {}
 
-    with Executor(max_workers=workers) as exe:
-        for file_type in types:
-            full_path = os.path.join(os.getcwd(), path)
-            files = chain(
-                Path(full_path).rglob(file_type),
-                Path(full_path).rglob(file_type.upper()),
-            )
+    with ThreadPoolExecutor(max_workers=workers) as exe:
+        jobs = {
+            exe.submit(
+                extract_invoice,
+                read_pdf(str(filename)),
+                services.extractor_endpoint,
+                guess(str(filename)).mime,
+                getattr(services, "token", None),
+            ): filename
+            for filename in files
+            if guess(str(filename)).mime
+        }
+        label = f"Converting {len(jobs)} invoices"
 
-            # TODO: Put validation request inside of IE request job.
-            jobs = [
-                exe.submit(
-                    extract_invoice,
-                    read_pdf(str(filename)),
-                    extractor_endpoint,
-                    guess(str(filename)).mime,
-                    token,
-                )
-                for filename in files
-                if guess(str(filename)).mime
-            ]
-            label = f"Converting {len(jobs)} invoices with {file_type} extension"
-            with click.progressbar(jobs, label=label) as bar:
-                for id, job in enumerate(bar):
-                    file_path = None
-                    try:
-                        file_path, extracted_invoice = job.result(timeout=300)
+        with click.progressbar(jobs, label=label) as bar:
+            for idx, future in enumerate(as_completed(jobs)):
+                file_name = str(jobs[future]).split("/")[-1]
+                validated_invoice = None
 
-                        # TODO: Move this to extract_invoice function.
-                        if "error" in extracted_invoice["infos"]:
-                            error = extracted_invoice["infos"]["error"]
-                            raise InvoiceExtractorException(
-                                f"Error in Invoice Extractor: {error}"
-                            )
+                try:
+                    extracted_invoice = future.result(timeout=300)
 
-                        if validation_endpoint:
-                            validated_invoice = validation(
-                                extracted_invoice, validation_endpoint
-                            )
-                        else:
-                            validated_invoice = None
-
-                        if vat_validation_endpoint:
-                            vat_validated_invoice = validate_vat(
-                                extracted_invoice, vat_validation_endpoint
-                            )
-                            vat_validation_result[file_count] = vat_validated_invoice
-
-                        result[file_count] = flatten_invoice(
-                            extracted_invoice, validated_invoice,
+                    if getattr(services, "validation_endpoint", None):
+                        validated_invoice = validation(
+                            extracted_invoice, services.validation_endpoint
                         )
-                    except Exception as e:
-                        result[file_count] = {}
-                        result[file_count]["error_message"] = (repr(e), None, None)
-                    finally:
-                        file_name = file_path.split("/")[-1] if file_path else None
-                        result[file_count]["file_name"] = (file_name, None, None)
-                        vat_validation_result[file_count]["file_name"] = file_name
 
-                    collect_column_names(
-                        result[file_count], single_fieldnames, multi_fieldnames
-                    )
+                    if getattr(services, "vat_validation_endpoint", None):
+                        vat_validation_result[idx] = validate_vat(
+                            extracted_invoice, services.vat_validation_endpoint
+                        )
+                        vat_validation_result[idx]["file_name"] = file_name
+
+                    result[idx] = flatten_invoice(extracted_invoice, validated_invoice,)
+                except Exception as e:
+                    result[idx] = {"error_message": (repr(e), None, None)}
+                finally:
+                    result[idx]["file_name"] = (file_name, None, None)
+
+                collect_column_names(result[idx], single_fieldnames, multi_fieldnames)
+                bar.update(1)
 
-                    file_count += 1
     if not result:
-        quit(f"No files of extension: {types} found in path")
-
+        quit(f"No files found in path")
     return (
         result,
         single_fieldnames,
@@ -122,14 +77,14 @@ def run_requests(
 def flatten_invoice(invoice, validation):
     return_dict = dict()
     entities = invoice["entities"]
-    probabilities = invoice["probabilities"]
+    probabilities = invoice.get("probabilities")
 
     def traverse_items(entities, probabilities, validation, _dict, *prefix):
         for k, v in entities.items():
             if isinstance(v, dict):
                 traverse_items(
                     entities[k],
-                    probabilities[k],
+                    probabilities[k] if probabilities else None,
                     validation[k][0] if validation and k in validation else None,
                     return_dict,
                     k,
@@ -143,7 +98,7 @@ def flatten_invoice(invoice, validation):
                             temp_dict[f"{k}_{item}_{counter}"] = value
                         traverse_items(
                             temp_dict,
-                            probabilities[k][counter],
+                            probabilities[k][counter] if probabilities else None,
                             validation[k][0][str(counter)][0]
                             if validation
                             and k in validation
@@ -163,7 +118,7 @@ def flatten_invoice(invoice, validation):
                 else:
                     field_name = k
 
-                if original_k in probabilities:
+                if probabilities and original_k in probabilities:
                     if probabilities[original_k]:
                         _dict[field_name] = (v, probabilities[original_k], None)
                     else:
@@ -193,3 +148,21 @@ def collect_column_names(extracted_invoice, single_fieldnames, multi_fieldnames)
             multi_fieldnames[label] = (None, None, None)
         else:
             single_fieldnames[col_name] = (None, None, None)
+
+
+def read_pdf(pdf_path):
+    with open(pdf_path, "rb") as pdf:
+        pdf = pdf.read()
+
+    return pdf
+
+
+def get_filenames(path):
+    types = ("*.pdf", "*.tif", "*.tiff", "*.png", "*.jpg")
+
+    files_grabbed = []
+    for files in types:
+        files_grabbed.extend(Path(path).rglob(files))
+        files_grabbed.extend(Path(path).rglob(files.upper()))
+
+    return files_grabbed
