@@ -4,24 +4,23 @@ from operator import itemgetter
 from copy import deepcopy
 
 from .commons import run_requests
+from ..services.services import Services
 
 
 def convert_to_csv(
-    path,
-    extractor_endpoint,
-    vat_validator_endpoint=None,
-    validation_endpoint=None,
-    token=None,
-    workers=6,
+    input_path: str,
+    services: Services,
+    workers: int = 1,
+    output_path: str = None,
     probability=False,
 ):
     # TODO: Make different csv output for multi card
     # Get requests result
-    result, single_fieldnames, multi_fieldnames, default_cols = run_requests(
-        workers, path, extractor_endpoint, validation_endpoint, token,
+    (result, single_fieldnames, multi_fieldnames, default_cols, _) = run_requests(
+        workers, input_path, services
     )
     # fieldnames = set().union(single_fieldnames, multi_fieldnames)
-    processed_dir_name = os.path.normpath(path).split(os.path.sep)[-1]
+    processed_dir_name = os.path.normpath(output_path).split(os.path.sep)[-1]
     structure_result(result)
 
     with open(f"{processed_dir_name}_single_cardinality.csv", mode="w") as f:
