@@ -5,16 +5,11 @@ import xlsxwriter
 
 from .commons import run_requests
 from .consts import RED_TO_GREEN_GRADIENT
+from ..services.services import Services
 
 
 def convert_to_xlsx(
-    path: str,
-    extractor_endpoint: str,
-    vat_validator_endpoint: str = None,
-    validation_endpoint: str = None,
-    token: str = None,
-    workers: int = 6,
-    output_path: str = None,
+    input_path: str, services: Services, workers: int = 1, output_path: str = None,
 ):
     """Sends requests to defined Hypatos services for every invoice found in given
     directory. Merges results off all services into one Excel file and writes to
@@ -31,10 +26,10 @@ def convert_to_xlsx(
         vat_validator_endpoint {str} -- Url of vat_validator. (default: {None})
         validation_endpoint {str} -- Url of validation. (default: {None})
         token {str} -- API token. (default: {None})
-        workers {int} -- Amount of multithread. (default: {6})
+        workers {int} -- Amount of multithread. (default: {3})
     """
     if not output_path:
-        output_path = f"{os.path.normpath(path).split(os.path.sep)[-1]}.xlsx"
+        output_path = f"{os.path.normpath(input_path).split(os.path.sep)[-1]}.xlsx"
     else:
         output_path = f"{os.path.join(os.getcwd(), output_path)}"
         if not os.path.isdir(os.path.sep.join(output_path.split(os.path.sep)[:-1])):
@@ -47,14 +42,7 @@ def convert_to_xlsx(
         multi_fieldnames,
         default_cols,
         vat_validation_result,
-    ) = run_requests(
-        workers,
-        path,
-        extractor_endpoint,
-        vat_validator_endpoint,
-        validation_endpoint,
-        token,
-    )
+    ) = run_requests(workers, input_path, services)
 
     # Structure result
     single_cardinality, multi_cardinality = structure_cardinality(
@@ -79,7 +67,7 @@ def convert_to_xlsx(
         header,
         probability_format,
         default_cols,
-        validation_endpoint,
+        services.validation_endpoint,
     )
 
     write_multi_cardinality(
@@ -88,7 +76,7 @@ def convert_to_xlsx(
         header,
         probability_format,
         default_cols,
-        validation_endpoint,
+        services.validation_endpoint,
     )
 
     if vat_validation_result:
@@ -178,7 +166,7 @@ def write_single_cardinality(
             column_value, probability, validation_errors = value
 
             if probability:
-                color_idx = int(len(red_to_green_formats) * probability)
+                color_idx = int((len(red_to_green_formats) - 1) * probability)
                 color = red_to_green_formats[color_idx]
                 worksheet.write(idx + 1, count, column_value, color)
             else:
@@ -225,7 +213,7 @@ def write_multi_cardinality(
                 column_value, probability, validation_errors = value
 
                 if probability:
-                    color_idx = int(len(red_to_green_formats) * probability)
+                    color_idx = int((len(red_to_green_formats) - 1) * probability)
                     color = red_to_green_formats[color_idx]
                     worksheet.write(item_count, count, column_value, color)
                 else:
