@@ -25,13 +25,14 @@ def extract_invoice(file, extractor_endpoint, content_type, token=None):
     """ Request invoice extractor """
     response = requests.post(
         url=extractor_endpoint,
-        data=file[1],
+        data=file,
         params={"rasterization": "true", "probabilities": "true"},
         timeout=1800,
         headers={"Content-type": content_type, "Authorization": f"Bearer {token}"},
     )
+
     response.raise_for_status()
-    return file[0], response.json()
+    return response.json()
 
 
 @handle_status_code
